@@ -2,9 +2,9 @@ package Linux::Info::Distribution::Custom::Amazon;
 
 use warnings;
 use strict;
-use parent 'Linux::Info::Distribution::Custom';
+use base 'Linux::Info::Distribution::Custom';
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 # ABSTRACT: a subclass of Linux::Info::Distribution::Custom
 
 
@@ -35,7 +35,7 @@ Linux::Info::Distribution::Custom::Amazon - a subclass of Linux::Info::Distribut
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head1 EXPORTS
 
