@@ -2,14 +2,14 @@ package Linux::Info::Distribution::Custom::RedHat;
 
 use warnings;
 use strict;
-use parent 'Linux::Info::Distribution::Custom';
+use base 'Linux::Info::Distribution::Custom';
 use Class::XSAccessor getters => {
     is_enterprise => 'enterprise',
     get_type      => 'type',
     get_codename  => 'codename'
 };
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 
 # ABSTRACT: a subclass of Linux::Info::Distribution::Custom
 
@@ -54,7 +54,7 @@ Linux::Info::Distribution::Custom::RedHat - a subclass of Linux::Info::Distribut
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head2 DESCRIPTION
 
