@@ -2,11 +2,11 @@ package Linux::Info::Distribution::OSRelease::Alpine;
 
 use warnings;
 use strict;
-use parent 'Linux::Info::Distribution::OSRelease';
+use base 'Linux::Info::Distribution::OSRelease';
 use Hash::Util qw(lock_hash unlock_hash);
 use Class::XSAccessor getters => { get_bug_report_url => 'bug_report_url' };
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 # ABSTRACT: a subclass of Linux::Info::Distribution::OSRelease
 
 
@@ -42,7 +42,7 @@ Linux::Info::Distribution::OSRelease::Alpine - a subclass of Linux::Info::Distri
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head1 DESCRIPTION
 
