@@ -2,14 +2,14 @@ package Linux::Info::Distribution::OSRelease::Amazon;
 
 use warnings;
 use strict;
-use parent 'Linux::Info::Distribution::OSRelease';
+use base 'Linux::Info::Distribution::OSRelease';
 use Hash::Util qw(lock_hash unlock_hash);
 use Class::XSAccessor getters => {
     get_ansi_color => 'ansi_color',
     get_cpe_name   => 'cpe_name',
 };
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 # ABSTRACT: a subclass of Linux::Info::Distribution::OSRelease
 
 
@@ -44,7 +44,7 @@ Linux::Info::Distribution::OSRelease::Amazon - a subclass of Linux::Info::Distri
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head1 DESCRIPTION
 
