@@ -2,7 +2,7 @@ package Linux::Info::Distribution::OSRelease::Rocky;
 
 use warnings;
 use strict;
-use parent 'Linux::Info::Distribution::OSRelease';
+use base 'Linux::Info::Distribution::OSRelease';
 use Hash::Util qw(lock_hash unlock_hash);
 use Class::XSAccessor getters => {
     get_platform_id                    => 'platform_id',
@@ -17,7 +17,7 @@ use Class::XSAccessor getters => {
     get_redhat_support_product_version => 'redhat_support_product_version',
 };
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 
 # ABSTRACT: a subclass of Linux::Info::Distribution::OSRelease
 
@@ -59,7 +59,7 @@ Linux::Info::Distribution::OSRelease::Rocky - a subclass of Linux::Info::Distrib
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head1 DESCRIPTION
 
