@@ -25,7 +25,7 @@ use Linux::Info::SysInfo::CPU::Arm;
 use Linux::Info::SysInfo::CPU::AMD;
 use Linux::Info::SysInfo::CPU::S390;
 
-our $VERSION = '2.17'; # VERSION
+our $VERSION = '2.18'; # VERSION
 
 my @_attribs = (
     'raw_time',   'hostname', 'domain', 'kernel',
@@ -50,7 +50,6 @@ sub new {
       : ( $raw_time = 0 );
 
     my %self = (
-        arch     => ( uname() )[4],    # TODO: useless?
         raw_time => $raw_time,
         files    => {},
     );
@@ -314,7 +313,7 @@ Linux::Info::SysInfo - Collect linux system information.
 
 =head1 VERSION
 
-version 2.17
+version 2.18
 
 =head1 SYNOPSIS
 
@@ -327,22 +326,39 @@ version 2.17
 
 Linux::Info::SysInfo gathers system information from the virtual F</proc> filesystem (procfs).
 
-For more information read the documentation of the front-end module L<Linux::Info>.
-
 This class interface is B<incompatible> with L<Sys::Statistics::Linux::SysInfo>.
 
-=head1 ATTRIBUTES
+See the methods available to know which information is available.
 
-Generated by F</proc/sys/kernel/{hostname,domainname,ostype,osrelease,version}>
-and F</proc/cpuinfo>, F</proc/meminfo>, F</proc/uptime>, F</proc/net/dev>.
+This class can identify and parse CPU information from the following vendors:
+
+=over
+
+=item *
+
+Intel
+
+=item *
+
+AMD
+
+=item *
+
+ARM
+
+=item *
+
+IBM (s390 only)
+
+=back
 
 =head1 METHODS
 
-=head2 new()
+=head2 new
 
-Call C<new()> to create a new object.
+Call C<new> to create a new object.
 
-    my $lxs = Linux::Info::SysInfo->new();
+    my $lxs = Linux::Info::SysInfo->new;
 
 Without any parameters.
 
@@ -442,8 +458,8 @@ other words, the first CPU found).
 
 =head2 get_cpu_flags
 
-Returns an array reference with all flags retrieve from C</proc/cpuinfo> using the same logic described in
-C<get_proc_arch> documentation.
+Returns an array reference with all flags retrieve from C</proc/cpuinfo> using
+the same logic described in C<get_proc_arch> documentation.
 
 =head2 get_model
 
@@ -451,8 +467,8 @@ A getter for the C<model> attribute.
 
 =head2 get_detailed_kernel
 
-Returns an instance of L<Linux::Info::KernelRelease> with all possible
-information that is available.
+Returns an instance of L<Linux::Info::KernelRelease> with all information that
+is possible to retrieve.
 
 =head1 EXPORTS
 
@@ -460,7 +476,8 @@ Nothing.
 
 =head1 KNOWN ISSUES
 
-Linux running on ARM processors have a different interface on F</proc/cpuinfo>.
+Linux running on ARM processors have a different interface in F</proc/cpuinfo>
+file.
 
 That means that the methods C<get_proc_arch> and C<get_cpu_flags> will not
 return their respective information. Tests for this module may fail as well.
